@@ -14,7 +14,7 @@
 #include <KConfigGroup>
 #include <KLocalizedString>
 // Qt
-#include <QImage>
+#include <QApplication>
 #include <QPainter>
 #include <QPixmap>
 #include <QRectF>
@@ -160,23 +160,24 @@ const QPixmap ThemeManager::getPixmap(const QString &svgid, QSize size)
     if (size.width() < 1 || size.height() < 1)
         qCCritical(KFOURINLINE_LOG) << "ThemeManager::getPixmap Cannot create svgid ID " << svgid << " with zero size" << size;
 
-    QPixmap pixmap;
+    const qreal dpr = qApp->devicePixelRatio();
+    size *= dpr;
 
     //  Cached pixmap?
     if (mPixmapCache.contains(svgid)) {
-        pixmap = mPixmapCache[svgid];
+        const QPixmap pixmap = mPixmapCache[svgid];
         if (pixmap.size() == size) {
             return pixmap;
         }
     }
 
     // Create new image
-    QImage image(size, QImage::Format_ARGB32_Premultiplied);
-    image.fill(0);
-    QPainter p(&image);
+    QPixmap pixmap(size);
+    pixmap.fill(Qt::transparent);
+    QPainter p(&pixmap);
     mRenderer->render(&p, svgid);
     p.end();
-    pixmap = QPixmap::fromImage(image);
+    pixmap.setDevicePixelRatio(dpr);
     if (pixmap.isNull())
         qCCritical(KFOURINLINE_LOG) << "ThemeManager::getPixmap Cannot load svgid ID " << svgid;
 
@@ -186,24 +187,22 @@ const QPixmap ThemeManager::getPixmap(const QString &svgid, QSize size)
     return pixmap;
 }
 
-// Get a pixmap when only width is given (this keeps the aspect ratio)
-const QPixmap ThemeManager::getPixmap(const QString &svgid, double width)
+// Get the size when only width is given (this keeps the aspect ratio)
+QSize ThemeManager::pixmapSize(const QString &svgid, double width) const
 {
     QRectF rect = mRenderer->boundsOnElement(svgid);
     double factor = width / rect.width();
-    QSize size = QSize(int(width), int(rect.height() * factor));
-    return getPixmap(svgid, size);
+    return QSize(int(width), int(rect.height() * factor));
 }
 
-// Get a pixmap with original properties and a scale factor given with respect to
+// Get the size with original properties and a scale factor given with respect to
 // another SVG item.
-const QPixmap ThemeManager::getPixmap(const QString &svgid, const QString &svgref, double refwidth)
+QSize ThemeManager::pixmapSize(const QString &svgid, const QString &svgref, double refwidth)
 {
     QRectF refrect = mRenderer->boundsOnElement(svgref);
     QRectF rect = mRenderer->boundsOnElement(svgid);
     double factor = refwidth / refrect.width();
-    QSize size = QSize(int(rect.width() * factor), int(rect.height() * factor));
-    return getPixmap(svgid, size);
+    return QSize(int(rect.width() * factor), int(rect.height() * factor));
 }
 
 // ========================== Themeable interface ===============================
